@@ -526,3 +526,65 @@ class LcovTest(CoverageTest):
             """)
         actual_result = self.get_lcov_report_content()
         assert expected_result == actual_result
+
+    def test_always_raise(self) -> None:
+        self.make_file("always_raise.py", """\
+            try:
+                if not_defined:
+                    print("Yes")
+                else:
+                    print("No")
+            except Exception:
+                pass
+        """)
+        cov = coverage.Coverage(source=".", branch=True)
+        self.start_import_stop(cov, "always_raise")
+        cov.lcov_report()
+        expected_result = textwrap.dedent("""\
+            SF:always_raise.py
+            DA:1,1
+            DA:2,1
+            DA:3,0
+            DA:5,0
+            DA:6,1
+            DA:7,1
+            LF:6
+            LH:4
+            BRDA:2,0,jump to line 3,-
+            BRDA:2,0,jump to line 5,-
+            BRF:2
+            BRH:0
+            end_of_record
+            """)
+        actual_result = self.get_lcov_report_content()
+        assert expected_result == actual_result
+
+    def test_multiline_conditions(self) -> None:
+        self.make_file("multi.py", """\
+            def fun(x):
+                if (
+                    x
+                ):
+                    print("got here")
+            """)
+        cov = coverage.Coverage(source=".", branch=True)
+        self.start_import_stop(cov, "multi")
+        cov.lcov_report()
+        lcov = self.get_lcov_report_content()
+        assert "BRDA:2,0,return from function 'fun',-" in lcov
+
+    def test_module_exit(self) -> None:
+        self.make_file("modexit.py", """\
+            #! /usr/bin/env python
+            def foo():
+                return bar(
+                )
+            if "x" == "y":  # line 5
+                foo()
+            """)
+        cov = coverage.Coverage(source=".", branch=True)
+        self.start_import_stop(cov, "modexit")
+        cov.lcov_report()
+        lcov = self.get_lcov_report_content()
+        print(lcov)
+        assert "BRDA:5,0,exit the module,1" in lcov
