@@ -10,14 +10,14 @@ import io
 import math
 import os.path
 
-from typing import Any, Dict, List, Optional
+from typing import Any, Iterable
 from xml.etree import ElementTree
 
 import pytest
 
 import coverage
 from coverage import Coverage
-from coverage.control import Plugins
+from coverage.plugin_support import Plugins
 from coverage.data import line_counts, sorted_lines
 from coverage.exceptions import CoverageWarning, NoSource, PluginError
 from coverage.misc import import_local_file
@@ -33,16 +33,16 @@ from tests.helpers import CheckUniqueFilenames, swallow_warnings
 class NullConfig(TPluginConfig):
     """A plugin configure thing when we don't really need one."""
     def get_plugin_options(self, plugin: str) -> TConfigSectionOut:
-        return {}
+        return {}   # pragma: never called
 
 
 class FakeConfig(TPluginConfig):
     """A fake config for use in tests."""
 
-    def __init__(self, plugin: str, options: Dict[str, Any]) -> None:
+    def __init__(self, plugin: str, options: dict[str, Any]) -> None:
         self.plugin = plugin
         self.options = options
-        self.asked_for: List[str] = []
+        self.asked_for: list[str] = []
 
     def get_plugin_options(self, plugin: str) -> TConfigSectionOut:
         """Just return the options for `plugin` if this is the right module."""
@@ -53,8 +53,18 @@ class FakeConfig(TPluginConfig):
             return {}
 
 
+def make_plugins(
+    modules: Iterable[str],
+    config: TPluginConfig,
+) -> Plugins:
+    """Construct a Plugins and call plugins.load_from_config() for convenience."""
+    plugins = Plugins()
+    plugins.load_from_config(modules, config)
+    return plugins
+
+
 class LoadPluginsTest(CoverageTest):
-    """Test Plugins.load_plugins directly."""
+    """Test Plugins construction."""
 
     def test_implicit_boolean(self) -> None:
         self.make_file("plugin1.py", """\
@@ -68,10 +78,10 @@ class LoadPluginsTest(CoverageTest):
             """)
 
         config = FakeConfig("plugin1", {})
-        plugins = Plugins.load_plugins([], config)
+        plugins = make_plugins([], config)
         assert not plugins
 
-        plugins = Plugins.load_plugins(["plugin1"], config)
+        plugins = make_plugins(["plugin1"], config)
         assert plugins
 
     def test_importing_and_configuring(self) -> None:
@@ -88,7 +98,7 @@ class LoadPluginsTest(CoverageTest):
             """)
 
         config = FakeConfig("plugin1", {'a': 'hello'})
-        plugins = list(Plugins.load_plugins(["plugin1"], config))
+        plugins = list(make_plugins(["plugin1"], config))
 
         assert len(plugins) == 1
         assert plugins[0].this_is == "me"                   # type: ignore
@@ -119,7 +129,7 @@ class LoadPluginsTest(CoverageTest):
             """)
 
         config = FakeConfig("plugin1", {'a': 'hello'})
-        plugins = list(Plugins.load_plugins(["plugin1", "plugin2"], config))
+        plugins = list(make_plugins(["plugin1", "plugin2"], config))
 
         assert len(plugins) == 2
         assert plugins[0].this_is == "me"                   # type: ignore
@@ -129,7 +139,7 @@ class LoadPluginsTest(CoverageTest):
 
         # The order matters...
         config = FakeConfig("plugin1", {'a': 'second'})
-        plugins = list(Plugins.load_plugins(["plugin2", "plugin1"], config))
+        plugins = list(make_plugins(["plugin2", "plugin1"], config))
 
         assert len(plugins) == 2
         assert plugins[0].options == {}                     # type: ignore
@@ -138,7 +148,7 @@ class LoadPluginsTest(CoverageTest):
 
     def test_cant_import(self) -> None:
         with pytest.raises(ImportError, match="No module named '?plugin_not_there'?"):
-            _ = Plugins.load_plugins(["plugin_not_there"], NullConfig())
+            _ = make_plugins(["plugin_not_there"], NullConfig())
 
     def test_plugin_must_define_coverage_init(self) -> None:
         self.make_file("no_plugin.py", """\
@@ -147,7 +157,7 @@ class LoadPluginsTest(CoverageTest):
             """)
         msg_pat = "Plugin module 'no_plugin' didn't define a coverage_init function"
         with pytest.raises(PluginError, match=msg_pat):
-            list(Plugins.load_plugins(["no_plugin"], NullConfig()))
+            list(make_plugins(["no_plugin"], NullConfig()))
 
 
 class PluginTest(CoverageTest):
@@ -207,7 +217,7 @@ class PluginTest(CoverageTest):
         cov._debug_file = debug_out
         cov.set_option("run:plugins", ["plugin_sys_info"])
         with swallow_warnings(
-            r"Plugin file tracers \(plugin_sys_info.Plugin\) aren't supported with .*"
+            r"Plugin file tracers \(plugin_sys_info.Plugin\) aren't supported with .*",
         ):
             cov.start()
         cov.stop()      # pragma: nested
@@ -272,6 +282,18 @@ class PluginTest(CoverageTest):
         out = self.run_command("coverage html -q")  # sneak in a test of -q
         assert out == ""
 
+    def test_coverage_init_plugins(self) -> None:
+        called = False
+        def coverage_init(reg: Plugins) -> None:    # pylint: disable=unused-argument
+            nonlocal called
+            called = True
+
+        cov = coverage.Coverage(plugins=[coverage_init])
+        # Calls _init() and loads plugins
+        cov.sys_info()
+
+        assert called
+
 
 @pytest.mark.skipif(testenv.PLUGINS, reason="This core doesn't support plugins.")
 class PluginWarningOnPyTracerTest(CoverageTest):
@@ -284,7 +306,8 @@ class PluginWarningOnPyTracerTest(CoverageTest):
 
         if testenv.PY_TRACER:
             core = "PyTracer"
-        elif testenv.SYS_MON:
+        else:
+            assert testenv.SYS_MON
             core = "SysMonitor"
 
         expected_warnings = [
@@ -412,8 +435,8 @@ class GoodFileTracerTest(FileTracerTest):
         analysis = cov._analyze("foo_7.html")
         assert analysis.statements == {1, 2, 3, 4, 5, 6, 7}
         # Plugins don't do branch coverage yet.
-        assert analysis.has_arcs() is True
-        assert analysis.arc_possibilities() == []
+        assert analysis.has_arcs is True
+        assert analysis.arc_possibilities == []
 
         assert analysis.missing == {1, 2, 3, 6, 7}
 
@@ -631,8 +654,8 @@ class BadFileTracerTest(FileTracerTest):
         module_name: str,
         plugin_name: str,
         our_error: bool = True,
-        excmsg: Optional[str] = None,
-        excmsgs: Optional[List[str]] = None,
+        excmsg: str | None = None,
+        excmsgs: list[str] | None = None,
     ) -> None:
         """Run a file, and see that the plugin failed.
 
@@ -1125,7 +1148,7 @@ class DynamicContextPluginTest(CoverageTest):
         ]
         assert expected == sorted(data.measured_contexts())
 
-        def assert_context_lines(context: str, lines: List[TLineNo]) -> None:
+        def assert_context_lines(context: str, lines: list[TLineNo]) -> None:
             data.set_query_context(context)
             assert lines == sorted_lines(data, filenames['rendering.py'])
 
@@ -1163,7 +1186,7 @@ class DynamicContextPluginTest(CoverageTest):
         ]
         assert expected == sorted(data.measured_contexts())
 
-        def assert_context_lines(context: str, lines: List[TLineNo]) -> None:
+        def assert_context_lines(context: str, lines: list[TLineNo]) -> None:
             data.set_query_context(context)
             assert lines == sorted_lines(data, filenames['rendering.py'])
 
