@@ -606,7 +606,7 @@ class ProcessTest(CoverageTest):
             """)
 
         # Some of our testing infrastructure can issue warnings.
-        # Turn it all off for the sub-process.
+        # Turn it all off for the subprocess.
         self.del_environ("COVERAGE_TESTING")
 
         out = self.run_command("python allok.py")
@@ -1101,6 +1101,8 @@ class CoverageCoreTest(CoverageTest):
         out = self.run_command("coverage run --debug=sys numbers.py")
         assert out.endswith("123 456\n")
         core = re_line(r" core:", out).strip()
+        # if env.PYBEHAVIOR.pep669:
+        #     assert core == "core: SysMonitor"
         if self.has_ctracer:
             assert core == "core: CTracer"
         else:
@@ -1140,6 +1142,14 @@ class CoverageCoreTest(CoverageTest):
             assert core in ("core: CTracer", "core: PyTracer")
             assert warns
 
+    def test_core_request_nosuchcore(self) -> None:
+        self.del_environ("COVERAGE_TEST_CORES")
+        self.set_environ("COVERAGE_CORE", "nosuchcore")
+        self.make_file("numbers.py", "print(123, 456)")
+        out = self.run_command("coverage run numbers.py")
+        assert "Unknown core value: 'nosuchcore'\n" in out
+        assert "123 456" not in out
+
 
 class FailUnderNoFilesTest(CoverageTest):
     """Test that nothing to report results in an error exit status."""
@@ -1197,9 +1207,9 @@ class YankedDirectoryTest(CoverageTest):
         assert all(line in out for line in lines)
 
 
-@pytest.mark.skipif(env.METACOV, reason="Can't test sub-process pth file during metacoverage")
+@pytest.mark.skipif(env.METACOV, reason="Can't test subprocess pth file during metacoverage")
 class ProcessStartupTest(CoverageTest):
-    """Test that we can measure coverage in sub-processes."""
+    """Test that we can measure coverage in subprocesses."""
 
     def setUp(self) -> None:
         super().setUp()
